<?php
/**
 * Template part for displaying front page team.
 *
 * @package Moral
 */

// Get default  mods value.
$team = get_theme_mod( 'emerge_team', 'custom' );

if ( 'disable' === $team ) {
	return;
}

$default = emerge_get_default_mods();
$section_title = get_theme_mod( 'emerge_team_title', $default['emerge_team_title'] );
$section_sub_title = get_theme_mod( 'emerge_team_sub_title', $default['emerge_team_sub_title'] );

?>
<div id="our-team" class="relative page-section">
	<div class="wrapper">
		<div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            <h5 class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></h5>
        </div><!-- .section-header -->

        <!-- .supports col-1, col-2, col-3, col-4 -->
        <?php
        $team_num = get_theme_mod( 'emerge_team_num', 4 );
        if ( $team_num > 4 ) {
        	if ( $team_num % 3 === 0 ) {
        		$col_class = 3;
        	} else {
        		$col_class = 4;
        	}
        } else {
        	$col_class = $team_num;
        }
        ?>
        <div class="section-content col-<?php echo esc_attr( $col_class );?>">
        	<?php

        	if (  in_array( $team, array( 'post', 'page', 'cat' ) ) ) {

        		if ( 'cat' === $team ) {
        			$cat_id = get_theme_mod( 'emerge_team_cat' );
        			$args = array(
        				'cat' => $cat_id,	
        				'posts_per_page' => $team_num,
        			);
        		} else {
        			$id = array();
        			$social_link_arr = array();
        			for ( $i=1; $i <= $team_num; $i++ ) { 
        				$id[] = get_theme_mod( "emerge_team_{$team}_" . $i );
        			}

        			$args = array(
        				'post_type' => $team,
        				'post__in' => (array)$id,	
        				'orderby'	=> 'post__in',
        				'posts_per_page' => $team_num,
        				'ignore_sticky_posts' => true,
        			);
        		}

        		$query = new WP_Query( $args );

        		if ( $query->have_posts() ) {
        			$k = 1;
        			while ( $query->have_posts() ) {
        				$query->the_post();
        				?>
			        	<article>
			        		<div class="featured-image"><a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'emerge-team', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?></a></div>
			        		<div class="entry-container">
			        			<header class="entry-header">
			        				<h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
			        					<span class="position"><?php echo get_theme_mod( 'emerge_team_custom_position_' . $k, $default['emerge_team_custom_position'] ); ?></span>
			        			</header>
			        			<ul class="social-icons">
			        				<?php 
			        				for ( $l=1; $l <= 3; $l++ ) { 
										$social_link = get_theme_mod( 'emerge_team_social_link_' . $l . '_' . $k, 'https://facebook.com' );
                                        if ( ! empty( $social_link ) ) {
										?>
				        				<li>
				        					<a href="<?php echo esc_url( $social_link ); ?>">
				        						<?php echo emerge_get_svg_by_url( $social_link ); ?>
											</a>
										</li>
									<?php } 
                                    }
                                    ?>
			        			</ul>
			        		</div><!-- .entry-container -->
			        	</article>
        			<?php	
        			$k++;
        			}
        			wp_reset_postdata();
        		}
        	} else {
        		for ( $i=1; $i <= $team_num; $i++ ) { 
        			$title   = get_theme_mod( 'emerge_team_custom_title_' . $i, $default['emerge_team_custom_title'] );
        			$url   = get_theme_mod( 'emerge_team_link_' . $i, '#' );
        			$img   = '<img src="' . esc_url( get_theme_mod( 'emerge_team_image_' . $i, $default['emerge_team_image'] ) ) . '" alt="' . esc_attr( $title ) . '">';
        			$team_position = get_theme_mod( 'emerge_team_custom_position_' . $i, $default['emerge_team_custom_position'] );
        			?>
		        	<article>
		        		<div class="featured-image"><a href="<?php echo esc_url( $url ); ?>"><?php echo $img ?></a></div>
		        		<div class="entry-container">
		        			<header class="entry-header">
		        				<h2 class="entry-title"><a href="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $title ); ?></a></h2>
		        				<span class="position"><?php echo esc_html( $team_position ); ?></span>
		        			</header>
		        			<ul class="social-icons">
		        				<?php  
				        		for ( $j=1; $j <= 3; $j++) { 
					        		$social_link = get_theme_mod( 'emerge_team_social_link_' . $j . '_' . $i, 'https://facebook.com' );
                                    if ( ! empty( $social_link ) ) {
					        		?>
			        				<li>
			        					<a href="<?php echo esc_url( $social_link ); ?>">
			        						<?php echo emerge_get_svg_by_url( $social_link ); ?>
			        					</a>
									</li>
				        		<?php 
                                    }
                                }	
                                ?>
		        			</ul>
		        		</div><!-- .entry-container -->
		        	</article>
        			<?php	
        		}
        	}
        	?>
        </div><!-- .section-content -->
	</div><!-- .wrapper -->
</div><!-- #our-team -->